@@ -1,4 +1,4 @@
-__version__ = "0.2.0"
+__version__ = "0.2.0.dev0"
 
 from .stats import (  # noqa
     norm_pdf,
@@ -12,4 +12,5 @@ from .stats import (  # noqa
     t_pdf,
     t_cdf,
     t_ppf,
+    voigt_pdf,
 )
